16.89. cdist-type__mysql_database(7) — cdist 6.1.1 documentation

# 16.89. cdist-type__mysql_database(7)

## 16.89.1. NAME

cdist-type__mysql_database - Manage a MySQL database

## 16.89.2. DESCRIPTION

This cdist type allows you to install a MySQL database.

## 16.89.3. REQUIRED PARAMETERS

None.

## 16.89.4. OPTIONAL PARAMETERS

name
  The name of the database to install defaults to the object id
user
  A user that should have access to the database
password
  The password for the user who manages the database

## 16.89.5. EXAMPLES

    __mysql_database "cdist" --name "cdist" --user "myuser" --password "mypwd"

## 16.89.6. AUTHORS

Benedikt Koeppel <code@benediktkoeppel.ch>

## 16.89.7. COPYING

Copyright (C) 2012 Benedikt Koeppel. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.